@@ -44,6 +44,7 @@ This module currently contains 6 formatters:
     in colour in a console using Rich (https://github.com/willmcgugan/rich).
 """
 from .my_gettext import current_lang
+from . import debug_helper
 
 from pygments import highlight
 from pygments.lexers import PythonLexer, PythonTracebackLexer  # noqa
@@ -51,7 +52,7 @@ from pygments.formatters import HtmlFormatter  # noqa
 
 
 ipython_available = False
-try:
+try:  # pragma: no cover
 
     from IPython.display import display, HTML  # noqa
 
@@ -137,7 +138,7 @@ def repl(info, include="friendly_tb"):
     return "\n".join(result)
 
 
-def html_escape(text):
+def html_escape(text):  # pragma: no cover
     text = (
         text.replace("&", "&amp;")
         .replace("<", "&lt;")
@@ -153,7 +154,7 @@ def html_escape(text):
 # For some reason, moving this to friendly.ipython
 # and trying to import it from there uninstalls everything: it is as though
 # it starts a new iPython subprocess.
-def jupyter(info, include="friendly_tb"):
+def jupyter(info, include="friendly_tb"):  # pragma: no cover
     """Jupyter formatter using pygments and html format."""
     _ = current_lang.translate
     css = HtmlFormatter().get_style_defs(".highlight")
@@ -214,7 +215,7 @@ if not ipython_available:
     jupyter = repl  # noqa
 
 
-def docs(info, include="friendly_tb"):
+def docs(info, include="friendly_tb"):  # pragma: no cover
     """Formatter that produces an output that is suitable for
     insertion in a RestructuredText (.rst) code block,
     with pre-formatted indentation.
@@ -248,7 +249,7 @@ def docs(info, include="friendly_tb"):
     return "\n".join(result)
 
 
-def markdown(info, include="friendly_tb"):
+def markdown(info, include="friendly_tb"):  # pragma: no cover
     """Traceback formatted with markdown syntax.
 
     Some minor changes of the traceback info content are done,
@@ -258,7 +259,7 @@ def markdown(info, include="friendly_tb"):
     return _markdown(info, include)
 
 
-def markdown_docs(info, include="explain"):
+def markdown_docs(info, include="explain"):  # pragma: no cover
     """Traceback formatted with markdown syntax, where each
     header is shifted down by 2 (h1 -> h3, etc.) so that they
     can be inserted in a document, without creating artificial
@@ -271,7 +272,7 @@ def markdown_docs(info, include="explain"):
     return _markdown(info, include, documentation=True)
 
 
-def rich_markdown(info, include="friendly_tb"):
+def rich_markdown(info, include="friendly_tb"):  # pragma: no cover
     """Traceback formatted with with markdown syntax suitable for
     printing in color in the console using Rich.
 
@@ -285,7 +286,7 @@ def rich_markdown(info, include="friendly_tb"):
     return _markdown(info, include, rich=True)
 
 
-def _markdown(info, include, rich=False, documentation=False):
+def _markdown(info, include, rich=False, documentation=False):  # pragma: no cover
     """Traceback formatted with with markdown syntax."""
     global RICH_HEADER
     RICH_HEADER = False
@@ -354,12 +355,15 @@ def no_result(info, include):
         return _("I have no suggestion to offer.")
 
     if include == "hint":
-        if info["cause"]:
+        if "cause" in info:
             return _("I have no suggestion to offer; try `why()`.")
 
         return _("I have no suggestion to offer.")
 
-    return f"Internal error: include = {include} in formatters.no_result()"
+    if True:  # pragma: no cover
+        debug_helper.log(
+            f"Internal error: include = {include} in formatters.no_result()"
+        )
 
 
 items_groups = {
