@@ -2,8 +2,8 @@
 as a replacement for the standard traceback in IPython."""
 
 try:
-    from IPython.core import interactiveshell as shell
-    from IPython.core import compilerop
+    from IPython.core import interactiveshell as shell  # noqa
+    from IPython.core import compilerop  # noqa
 except ImportError:
     raise ValueError("IPython cannot be imported.")
 
@@ -14,7 +14,7 @@ from friendly.console_helpers import *  # noqa
 from friendly.console_helpers import helpers  # noqa
 
 try:
-    from IPython.utils import py3compat
+    from IPython.utils import py3compat  # noqa
 
     exclude_file_from_traceback(py3compat.__file__)
 except Exception:  # noqa
@@ -28,14 +28,11 @@ __all__ = list(helpers.keys())
 
 
 def set_width(width=80):
-    """Sets the width in a Jupyter session using Rich."""
+    """Sets the width in a iPython/Jupyter session using Rich."""
     if session.use_rich:
         session.console._width = width
     else:
-        print(
-            "set_width() is only available using 'light' or 'dark' mode.",
-            session.use_rich,
-        )
+        print("set_width() is only available using 'light' or 'dark' mode.")
 
 
 __all__.append("set_width")
