@@ -9,7 +9,7 @@ from .. import utils
 def get_cause(value, frame, tb_data):
     try:
         return _get_cause(value, frame, tb_data)
-    except Exception as e:
+    except Exception as e:  # pragma: no cover
         debug_helper.log_error(e)
         return {"cause": internal_error(), "suggest": internal_error()}
 
