@@ -10,18 +10,13 @@ def add_message_parser(func):
     to the list of known parsers."""
     MESSAGES_PARSERS.append(func)
 
-    def wrapper(*args):
-        return func(*args)
-
-    return wrapper
-
 
 def get_cause(value, frame, tb_data):
     message = str(value)
     try:
         return _get_cause(message, frame, tb_data)
-    except Exception:  # noqa
-        debug_helper.log_error()
+    except Exception as e:  # pragma: no cover
+        debug_helper.log_error(e)
         return {"cause": internal_error(), "suggest": internal_error()}
 
 
