@@ -20,7 +20,7 @@ def more_errors():
     _ = current_lang.translate
     return "\n" + _(
         "However, making such a change would still not correct\n"
-        "all the syntax problems in the code you wrote.\n"
+        "all the syntax errors in the code you wrote.\n"
     )
 
 
@@ -43,7 +43,7 @@ def add_statement_analyzer(func):
 def analyze_statement(statement):
     """Analyzes the statement as identified by Python as that
     on which the error occurred."""
-    if not statement.tokens:
+    if not statement.tokens:  # pragma: no cover
         debug_helper.log("Statement with no tokens in statement_analyser.py")
         return {"cause": internal_error()}
 
@@ -336,6 +336,57 @@ def detect_walrus(statement):
     return {}
 
 
+@add_statement_analyzer
+def inverted_operators(statement):
+    """Detect if operators might have been inverted"""
+    _ = current_lang.translate
+
+    is_op = token_utils.is_operator
+    if not is_op(statement.bad_token):
+        return {}
+
+    prev = statement.prev_token
+    bad = statement.bad_token
+    next_ = statement.next_token
+
+    if is_op(prev) and is_op(bad.string + prev.string) and prev.immediately_before(bad):
+        first = prev
+        second = bad
+    elif (
+        is_op(next_)
+        and is_op(next_.string + bad.string)
+        and bad.immediately_before(next_)
+    ):
+        first = bad
+        second = next_
+    else:
+        return {}
+
+    correct = second.string + first.string
+    hint = _("Did you write operators in an incorrect order?\n")
+    cause = _(
+        "It looks like you wrote two operators (`{first}` and `{second}`)\n"
+        "in the wrong order: `{wrong}` instead of `{correct}`.\n"
+    ).format(
+        first=first.string,
+        second=second.string,
+        correct=correct,
+        wrong=first.string + second.string,
+    )
+
+    new_statement = fixers.replace_two_tokens(
+        statement.statement_tokens,
+        first,
+        first_string=correct,
+        second_token=second,
+        second_string="",
+    )
+    if fixers.check_statement(new_statement):
+        return {"cause": cause, "suggest": hint}
+
+    return {"cause": cause + more_errors(), "suggest": hint}
+
+
 @add_statement_analyzer
 def consecutive_operators(statement):
     _ = current_lang.translate
@@ -415,65 +466,10 @@ def space_between_operators(statement):
     return {"cause": cause + more_errors(), "suggest": hint}
 
 
-@add_statement_analyzer
-def inverted_comparison_operators(statement):
-    """Detect if comparison operators might have been inverted"""
-    _ = current_lang.translate
-
-    is_op = token_utils.is_operator
-    if not is_op(statement.bad_token):
-        return {}
-
-    prev = statement.prev_token
-    bad = statement.bad_token
-    next_ = statement.next_token
-
-    if (
-        is_op(prev)
-        and token_utils.is_comparison(bad.string + prev.string)
-        and prev.immediately_before(bad)
-    ):
-        first = prev
-        second = bad
-    elif (
-        is_op(next_)
-        and token_utils.is_comparison(next_.string + bad.string)
-        and bad.immediately_before(next_)
-    ):
-        first = bad
-        second = next_
-    else:
-        return {}
-
-    correct = second.string + first.string
-    hint = _("Did you write operators in an incorrect order?\n")
-    cause = _(
-        "It looks like you wrote two operators (`{first}` and `{second}`)\n"
-        "in the wrong order: `{wrong}` instead of `{correct}`.\n"
-    ).format(
-        first=first.string,
-        second=second.string,
-        correct=correct,
-        wrong=first.string + second.string,
-    )
-
-    new_statement = fixers.replace_two_tokens(
-        statement.statement_tokens,
-        first,
-        first_string=correct,
-        second_token=second,
-        second_string="",
-    )
-    if fixers.check_statement(new_statement):
-        return {"cause": cause, "suggest": hint}
-
-    return {"cause": cause + more_errors(), "suggest": hint}
-
-
 @add_statement_analyzer
 def walrus_instead_of_equal(statement):
     _ = current_lang.translate
-    if not statement.bad_token == ":=":
+    if statement.bad_token != ":=":
         return {}
 
     new_statement = fixers.replace_token(
@@ -844,7 +840,7 @@ def malformed_class_begin_code_block(statement):
     if statement.first_token != "class" or statement.bad_token != ":":
         return {}
 
-    if not statement.prev_token == statement.first_token:
+    if statement.prev_token != statement.first_token:
         return {}
 
     cause = _("You tried to define a class and did not use the correct syntax.\n")
@@ -874,7 +870,7 @@ def assign_to_a_keyword(statement):
 def lambda_with_paren(statement):
     _ = current_lang.translate
 
-    if not statement.bad_token == "(":
+    if statement.bad_token != "(":
         return {}
 
     if statement.prev_token == "lambda":
@@ -1325,7 +1321,7 @@ def and_instead_of_comma(statement):
     # Example: from math import sin and cos
     _ = current_lang.translate
 
-    if not statement.bad_token == "and":
+    if statement.bad_token != "and":
         return {}
 
     possible_cause = _(
@@ -1436,11 +1432,11 @@ def parens_around_exceptions(statement):
     # keep in sync with message_analyzer.parens_around_exceptions
     _ = current_lang.translate
 
-    if not (statement.bad_token == "," and statement.first_token == "except"):
+    if statement.bad_token != "," or statement.first_token != "except":
         return {}
 
     for tok in statement.tokens[1 : statement.bad_token_index]:
-        if not (tok.is_identifier() or tok == ","):
+        if not tok.is_identifier() and tok != ",":
             return {}
 
     hint = _("Did you forget parentheses?\n")
@@ -1459,6 +1455,54 @@ def parens_around_exceptions(statement):
     }
 
 
+@add_statement_analyzer
+def duplicate_token(statement):
+    _ = current_lang.translate
+    if statement.bad_token != statement.prev_token:
+        return {}
+    if len(statement.bad_token.string) == 1:
+        bad_token = "[`{bad_token}`]".format(bad_token=statement.bad_token)
+    else:
+        bad_token = "`{bad_token}`".format(bad_token=statement.bad_token)
+    cause = _(
+        "I am guessing that you wrote {bad_token} twice in a row by mistake.\n"
+        "If that is the case, you need to remove the second one.\n"
+    ).format(bad_token=bad_token)
+    hint = _("Did you write {bad_token} twice by mistake?\n").format(
+        bad_token=bad_token
+    )
+    new_statement = fixers.replace_token(
+        statement.statement_tokens, statement.bad_token, ""
+    )
+    if fixers.check_statement(new_statement):
+        return {"cause": cause, "suggest": hint}
+    else:
+        return {"cause": cause + more_errors(), "suggest": hint}
+
+
+@add_statement_analyzer
+def extra_token(statement):
+    _ = current_lang.translate
+    new_statement = fixers.replace_token(
+        statement.statement_tokens, statement.bad_token, ""
+    )
+
+    if fixers.check_statement(new_statement):
+        if len(statement.bad_token.string) == 1:
+            bad_token = "[`{bad_token}`]".format(bad_token=statement.bad_token)
+        else:
+            bad_token = "`{bad_token}`".format(bad_token=statement.bad_token)
+        cause = _(
+            "I am guessing that you wrote {bad_token} by mistake.\n"
+            "Removing it and writing `{line}` seems to fix the error.\n"
+        ).format(bad_token=bad_token, line=new_statement)
+        hint = _("Did you write {bad_token} by mistake?\n").format(
+            bad_token=bad_token
+        )
+        return {"cause": cause, "suggest": hint}
+    else:
+        return {}
+
 # Keep last
 @add_statement_analyzer
 def unclosed_bracket(statement):
